#nb_query

Python package to search in Jupyter notebooks.

[![Tests](https://github.com/xLaszlo/nb-query/workflows/Tests/badge.svg)](https://github.com/xLaszlo/nb-query/actions?workflow=Tests)
[![Codecov](https://codecov.io/gh/xLaszlo/nb-query/branch/master/graph/badge.svg)](https://codecov.io/gh/xLaszlo/nb-query)
[![PyPI](https://img.shields.io/pypi/v/nb-query.svg)](https://pypi.org/project/nb-query/)
